// main.js

// アプリケーションの寿命の制御と、ネイティブなブラウザウインドウを作成するモジュール
const { app, BrowserWindow } = require('electron')
const path = require('path')
var debug = false;

const createWindow = () => {
  var w = 400;
  // ブラウザウインドウを作成します。
  const mainWindow = new BrowserWindow({
    width: debug ? 900: 400,
    height: 600,
    webPreferences: {
        preload: path.join(__dirname, 'preload.js'),
        nodeIntegration: true,
        enebleRemoteModule: true
    }
  })

  // そしてアプリの index.html を読み込みます。
  mainWindow.loadFile('index.html')

  // デベロッパー ツールを開きます。
  if (debug) {
   mainWindow.webContents.openDevTools()
    
  }
}

// このメソッドは、Electron の初期化が完了し、
// ブラウザウインドウの作成準備ができたときに呼ばれます。
// 一部のAPIはこのイベントが発生した後にのみ利用できます。
app.whenReady().then(() => {
  createWindow()

  app.on('activate', () => {
    // macOS では、Dock アイコンのクリック時に他に開いているウインドウがない
    // 場合、アプリのウインドウを再作成するのが一般的です。
    if (BrowserWindow.getAllWindows().length === 0) createWindow()
  })
})

// macOS を除き、全ウインドウが閉じられたときに終了します。 ユーザーが
// Cmd + Q で明示的に終了するまで、アプリケーションとそのメニューバーを
// アクティブにするのが一般的です。
app.on('window-all-closed', () => {
  if (process.platform !== 'darwin') app.quit()
})

// このファイルでは、アプリ内のとある他のメインプロセスコードを
// インクルードできます。
// 別々のファイルに分割してここで require することもできます。
const { ipcMain } = require('electron')
const fs = require('fs')



ipcMain.handle('file_manage_process', (event, data) => {
    console.log("process called.")
  var file_list = data.file_list
    var folder_name = data.folder_name
    
      var current_folder = path.dirname(file_list[0]);
      var parent_folder = path.dirname(current_folder);
    var new_folder = path.join(parent_folder, folder_name);

    //console.log(new_folder);
    if (!fs.existsSync(new_folder)) {
        fs.mkdirSync(new_folder);
    }
    file_list.forEach(oldPath => {
      var file_name = path.basename(oldPath)
      var newPath = path.join(new_folder, file_name)
      //console.log(newPath);
      fs.rename(oldPath, newPath, function (err) {
              //callback();
          });
      })
})
